
CREATE SEQUENCE schedule_requests_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 68 (OID 52552673)
-- Name: course_subjects; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE course_subjects (
    syear numeric(4,0),
    school_id numeric,
    subject_id numeric NOT NULL,
    title character varying(100),
    short_name character varying(25),
    rollover_id numeric
);


--
-- TOC entry 69 (OID 52552678)
-- Name: courses; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE courses (
    syear numeric(4,0) NOT NULL,
    course_id numeric NOT NULL,
    subject_id numeric NOT NULL,
    school_id numeric NOT NULL,
    grade_level numeric,
    title character varying(100),
    short_name character varying(25),
    rollover_id numeric
);


--
-- TOC entry 4 (OID 52552683)
-- Name: course_subjects_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE course_subjects_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 70 (OID 52552685)
-- Name: school_gradelevels; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE school_gradelevels (
    id numeric NOT NULL,
    school_id numeric,
    short_name character varying(2),
    title character varying(50),
    next_grade_id numeric,
    sort_order numeric
);


--
-- TOC entry 71 (OID 52552690)
-- Name: custom_fields; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE custom_fields (
    id numeric NOT NULL,
    "type" character varying(10),
    search character varying(1),
    title character varying(30),
    sort_order numeric,
    select_options character varying(10000),
    category_id numeric,
    system_field character(1),
    required character varying(1),
    default_selection character varying(255)
);


--
-- TOC entry 72 (OID 52552695)
-- Name: custom; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE custom (
    student_id numeric NOT NULL
);


--
-- TOC entry 73 (OID 52552700)
-- Name: students; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE students (
    student_id numeric NOT NULL,
    last_name character varying(50) NOT NULL,
    first_name character varying(50) NOT NULL,
    middle_name character varying(50),
    name_suffix character varying(3),
    username character varying(100),
    "password" character varying(100),
    last_login timestamp(0) without time zone,
    failed_login numeric,
    custom_200000000 character varying(255),
    custom_200000001 character varying(255),
    custom_200000002 character varying(255),
    custom_200000003 character varying(255),
    custom_200000004 character varying(255),
    custom_200000005 character varying(255),
    custom_200000006 character varying(255),
    custom_200000007 character varying(255),
    custom_200000008 character varying(255),
    custom_200000009 character varying(2052),
    custom_200000010 character(1),
    custom_200000011 character varying(2052)
);


--
-- TOC entry 6 (OID 52552705)
-- Name: students_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE students_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 74 (OID 52552707)
-- Name: student_medical; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_medical (
    id numeric NOT NULL,
    student_id numeric,
    "type" character varying(25),
    medical_date date,
    comments character varying(100)
);


--
-- TOC entry 8 (OID 52552712)
-- Name: student_medical_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE student_medical_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 75 (OID 52552714)
-- Name: student_medical_alerts; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_medical_alerts (
    id numeric NOT NULL,
    student_id numeric,
    title character varying(100)
);


--
-- TOC entry 10 (OID 52552719)
-- Name: student_medical_alerts_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE student_medical_alerts_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 12 (OID 52552721)
-- Name: staff_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE staff_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 76 (OID 52552723)
-- Name: staff; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE staff (
    syear numeric(4,0),
    staff_id numeric NOT NULL,
    current_school_id numeric,
    title character varying(5),
    first_name character varying(100),
    last_name character varying(100),
    middle_name character varying(100),
    username character varying(100),
    "password" character varying(100),
    phone character varying(100),
    email character varying(100),
    profile character varying(30),
    homeroom character varying(5),
    schools character varying(255),
    last_login timestamp(0) without time zone,
    failed_login numeric,
    profile_id numeric,
    rollover_id numeric
);


--
-- TOC entry 77 (OID 52552728)
-- Name: config; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE config (
    title character varying(100),
    syear numeric(4,0),
    login character varying(3)
);


--
-- TOC entry 78 (OID 52552730)
-- Name: staff_exceptions; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE staff_exceptions (
    user_id numeric not null,
    modname character varying(255),
    can_use character varying(1),
    can_edit character varying(1)
);


--
-- TOC entry 14 (OID 52552732)
-- Name: attendance_codes_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE attendance_codes_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 79 (OID 52552734)
-- Name: attendance_codes; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_codes (
    id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    title character varying(100),
    short_name character varying(10),
    "type" character varying(10),
    state_code character varying(1),
    default_code character varying(1),
    table_name numeric,
    sort_order numeric
);


--
-- TOC entry 80 (OID 52552739)
-- Name: attendance_calendar; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_calendar (
    syear numeric(4,0) NOT NULL,
    school_id numeric NOT NULL,
    school_date date NOT NULL,
    minutes numeric,
    block character varying(10),
    calendar_id numeric NOT NULL
);


--
-- TOC entry 81 (OID 52552744)
-- Name: calendar_events; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE calendar_events (
    id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    school_date date,
    title character varying(50),
    description character varying(500)
);


--
-- TOC entry 16 (OID 52552749)
-- Name: calendar_events_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE calendar_events_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 82 (OID 52552751)
-- Name: school_years; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE school_years (
    marking_period_id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    title character varying(50),
    short_name character varying(10),
    sort_order numeric,
    start_date date,
    end_date date,
    post_start_date date,
    post_end_date date,
    does_grades character varying(1),
    does_exam character varying(1),
    does_comments character varying(1),
    rollover_id numeric
);


--
-- TOC entry 82 (OID 52552751)
-- Name: school_semesters; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE school_semesters (
    marking_period_id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    year_id numeric,
    title character varying(50),
    short_name character varying(10),
    sort_order numeric,
    start_date date,
    end_date date,
    post_start_date date,
    post_end_date date,
    does_grades character varying(1),
    does_exam character varying(1),
    does_comments character varying(1),
    rollover_id numeric
);


--
-- TOC entry 83 (OID 52552756)
-- Name: school_quarters; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE school_quarters (
    marking_period_id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    semester_id numeric,
    title character varying(50),
    short_name character varying(10),
    sort_order numeric,
    start_date date,
    end_date date,
    post_start_date date,
    post_end_date date,
    does_grades character varying(1),
    does_exam character varying(1),
    does_comments character varying(1),
    rollover_id numeric
);


--
-- TOC entry 84 (OID 52552761)
-- Name: school_progress_periods; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE school_progress_periods (
    marking_period_id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    quarter_id numeric,
    title character varying(50),
    short_name character varying(10),
    sort_order numeric,
    start_date date,
    end_date date,
    post_start_date date,
    post_end_date date,
    does_grades character varying(1),
    does_exam character varying(1),
    does_comments character varying(1),
    rollover_id numeric
);


--
-- TOC entry 18 (OID 52552766)
-- Name: marking_period_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE marking_period_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 85 (OID 52552768)
-- Name: attendance_period; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_period (
    student_id numeric NOT NULL,
    school_date date NOT NULL,
    period_id numeric NOT NULL,
    attendance_code numeric,
    attendance_teacher_code numeric,
    attendance_reason character varying(100),
    admin character varying(1),
    course_period_id numeric,
    marking_period_id numeric,
    comment character varying(100)
);


--
-- TOC entry 86 (OID 52552773)
-- Name: school_periods; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE school_periods (
    period_id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    sort_order numeric,
    title character varying(100),
    short_name character varying(10),
    length numeric,
    start_time character varying(5),
    end_time character varying(5),
    block character varying(10),
    attendance character varying(1),
    rollover_id numeric
);


--
-- TOC entry 87 (OID 52552778)
-- Name: course_weights; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE course_weights (
    syear numeric(4,0),
    school_id numeric,
    course_id numeric NOT NULL,
    course_weight character varying(10) NOT NULL,
    gpa_multiplier numeric,
    year_fraction numeric,
    rollover_id numeric
);


--
-- TOC entry 88 (OID 52552783)
-- Name: schedule; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE schedule (
    syear numeric(4,0) NOT NULL,
    school_id numeric,
    student_id numeric NOT NULL,
    start_date date NOT NULL,
    end_date date,
    modified_date date,
    modified_by character varying(255),
    course_id numeric NOT NULL,
    course_weight character varying(10) NOT NULL,
    course_period_id numeric NOT NULL,
    mp character varying(3),
    marking_period_id numeric,
    scheduler_lock character varying(1),
    id numeric
);


--
-- TOC entry 89 (OID 52552788)
-- Name: course_periods; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE course_periods (
    syear numeric(4,0) NOT NULL,
    school_id numeric NOT NULL,
    course_period_id numeric NOT NULL,
    course_id numeric NOT NULL,
    course_weight character varying(10) NOT NULL,
    title character varying(100),
    short_name character varying(25),
    period_id numeric,
    mp character varying(3),
    marking_period_id numeric,
    teacher_id numeric,
    room character varying(10),
    total_seats numeric,
    filled_seats numeric,
    does_attendance character varying(1),
    does_grades character varying(1),
    does_honor_roll character varying(1),
    does_class_rank character varying(1),
    gender_restriction character varying(1),
    house_restriction character varying(1),
    credits character varying(4),
    availability numeric,
    parent_id numeric,
    days character varying(7),
    calendar_id numeric,
    half_day character varying(1),
    does_breakoff character varying(1),
    rollover_id numeric
);


--
-- TOC entry 90 (OID 52552793)
-- Name: schedule_requests; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE schedule_requests (
    syear numeric(4,0),
    school_id numeric,
    request_id numeric NOT NULL,
    student_id numeric,
    subject_id numeric,
    course_id numeric,
    course_weight character varying(10),
    marking_period_id numeric,
    priority numeric,
    with_teacher_id numeric,
    not_teacher_id numeric,
    with_period_id numeric,
    not_period_id numeric
) WITHOUT OIDS;


--
-- TOC entry 91 (OID 52552798)
-- Name: address; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE address (
    address_id numeric(10,0) NOT NULL,
    house_no numeric(5,0),
    fraction character varying(3),
    letter character varying(2),
    direction character varying(2),
    street character varying(30),
    apt character varying(5),
    zipcode character varying(10),
    plus4 character varying(4),
    city character varying(60),
    state character varying(10),
    mail_street character varying(30),
    mail_city character varying(60),
    mail_state character varying(10),
    mail_zipcode character varying(10),
    address character varying(255),
    mail_address character varying(255),
    phone character varying(30)
);


--
-- TOC entry 92 (OID 52552800)
-- Name: students_join_address; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE students_join_address (
    id numeric(10,0) NOT NULL,
    student_id numeric NOT NULL,
    address_id numeric(10,0) NOT NULL,
    contact_seq numeric(10,0),
    gets_mail character varying(1),
    primary_residence character varying(1),
    legal_residence character varying(1),
    am_bus character varying(1),
    pm_bus character varying(1),
    mailing character varying(1),
    residence character varying(1),
    bus character varying(1),
    bus_pickup character varying(1),
    bus_dropoff character varying(1)
);


--
-- TOC entry 93 (OID 52552805)
-- Name: people; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE people (
    person_id numeric(10,0) NOT NULL,
    last_name character varying(25) NOT NULL,
    first_name character varying(25) NOT NULL,
    middle_name character varying(25)
);


--
-- TOC entry 94 (OID 52552807)
-- Name: students_join_people; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE students_join_people (
    id numeric(10,0) NOT NULL,
    student_id numeric NOT NULL,
    person_id numeric(10,0) NOT NULL,
    address_id numeric,
    custody character varying(1),
    emergency character varying(1),
    student_relation character varying(100)
);


--
-- TOC entry 95 (OID 52552812)
-- Name: attendance_day; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_day (
    student_id numeric NOT NULL,
    school_date date NOT NULL,
    minutes_present numeric,
    state_value numeric(2,1),
    syear numeric(4,0),
    marking_period_id numeric,
    "comment" character varying(255)
);


--
-- TOC entry 20 (OID 52552817)
-- Name: report_card_grades_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE report_card_grades_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 22 (OID 52552819)
-- Name: report_card_comments_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE report_card_comments_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 96 (OID 52552821)
-- Name: report_card_comments; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE report_card_comments (
    id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    course_id numeric,
    sort_order numeric,
    title character varying(100)
);


--
-- TOC entry 97 (OID 52552826)
-- Name: report_card_grades; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE report_card_grades (
    id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    title character varying(3),
    sort_order numeric,
    gpa_value numeric(4,2),
    break_off numeric,
    comment character varying(100)
);


--
-- TOC entry 98 (OID 52552831)
-- Name: attendance_completed; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_completed (
    staff_id numeric NOT NULL,
    school_date date NOT NULL,
    period_id numeric NOT NULL
);


--
-- TOC entry 99 (OID 52552836)
-- Name: student_report_card_grades; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_report_card_grades (
    syear numeric(4,0) NOT NULL,
    school_id numeric,
    student_id numeric NOT NULL,
    course_period_id numeric NOT NULL,
    report_card_grade_id numeric,
    report_card_comment_id numeric,
    "comment" character varying(255),
    grade_percent numeric(4,1),
    marking_period_id character varying(10) NOT NULL
);


--
-- TOC entry 99 (OID 52552836)
-- Name: student_report_card_commentss; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_report_card_comments (
    syear numeric(4,0) NOT NULL,
    school_id numeric,
    student_id numeric NOT NULL,
    course_period_id numeric NOT NULL,
    report_card_comment_id numeric not null,
    "comment" character varying(1),
    marking_period_id character varying(10) NOT NULL
);


--
-- TOC entry 100 (OID 52552841)
-- Name: grades_completed; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE grades_completed (
    staff_id numeric NOT NULL,
    marking_period_id character varying(10) NOT NULL,
    period_id numeric NOT NULL
);


--
-- TOC entry 101 (OID 52552856)
-- Name: eligibility_activities; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE eligibility_activities (
    id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    title character varying(100),
    start_date date,
    end_date date
);


--
-- TOC entry 24 (OID 52552861)
-- Name: eligibility_activities_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE eligibility_activities_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 102 (OID 52552863)
-- Name: eligibility; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE eligibility (
    student_id numeric,
    syear numeric(4,0),
    school_date date,
    period_id numeric,
    eligibility_code character varying(20),
    course_period_id numeric
);


--
-- TOC entry 103 (OID 52552868)
-- Name: eligibility_completed; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE eligibility_completed (
    staff_id numeric NOT NULL,
    school_date date NOT NULL,
    period_id numeric NOT NULL
);


--
-- TOC entry 104 (OID 52552873)
-- Name: program_config; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE program_config (
    syear numeric(4,0),
    school_id numeric,
    program character varying(255),
    title character varying(100),
    value character varying(100)
);


--
-- TOC entry 105 (OID 52552878)
-- Name: student_eligibility_activities; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_eligibility_activities (
    syear numeric(4,0),
    student_id numeric,
    activity_id numeric
);


--
-- TOC entry 106 (OID 52552883)
-- Name: gradebook_assignment_types; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gradebook_assignment_types (
    assignment_type_id numeric NOT NULL,
    staff_id numeric,
    course_id numeric,
    title character varying(100),
    final_grade_percent numeric(6,5)
);


--
-- TOC entry 26 (OID 52552888)
-- Name: gradebook_assignment_types_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE gradebook_assignment_types_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 28 (OID 52552890)
-- Name: gradebook_assignments_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE gradebook_assignments_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 107 (OID 52552892)
-- Name: gradebook_assignments; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gradebook_assignments (
    assignment_id numeric NOT NULL,
    staff_id numeric,
    marking_period_id numeric,
    course_period_id numeric,
    course_id numeric,
    assignment_type_id numeric,
    title character varying(100),
    assigned_date date,
    due_date date,
    points numeric,
    description character varying(1000)
);


--
-- TOC entry 108 (OID 52552897)
-- Name: gradebook_grades; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE gradebook_grades (
    student_id numeric NOT NULL,
    period_id numeric,
    course_period_id numeric NOT NULL,
    assignment_id numeric NOT NULL,
    points numeric(6,2),
    "comment" character varying(100)
);


--
-- TOC entry 109 (OID 52552902)
-- Name: program_user_config; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE program_user_config (
    user_id numeric not null,
    program character varying(255),
    title character varying(100),
    value character varying(100)
);


--
-- TOC entry 30 (OID 52552904)
-- Name: courses_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE courses_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 32 (OID 52552906)
-- Name: school_periods_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE school_periods_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 34 (OID 52552908)
-- Name: school_gradelevels_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE school_gradelevels_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 36 (OID 52552910)
-- Name: course_periods_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE course_periods_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 38 (OID 52552912)
-- Name: schools_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE schools_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 110 (OID 52552914)
-- Name: schools; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE schools (
    syear numeric(4,0),
    id numeric NOT NULL,
    title character varying(100),
    address character varying(100),
    city character varying(100),
    state character varying(2),
    zipcode character varying(10),
    area_code numeric(3,0),
    phone numeric(7,0),
    principal character varying(100)
);


--
-- TOC entry 40 (OID 52552919)
-- Name: custom_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE custom_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 111 (OID 52552921)
-- Name: student_enrollment_codes; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_enrollment_codes (
    id numeric,
    syear numeric(4,0),
    title character varying(100),
    short_name character varying(10),
    "type" character varying(4)
);


--
-- TOC entry 42 (OID 52552926)
-- Name: student_enrollment_codes_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE student_enrollment_codes_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 112 (OID 52552928)
-- Name: student_enrollment; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_enrollment (
    id numeric NOT NULL,
    syear numeric(4,0),
    school_id numeric,
    student_id numeric,
    grade_id numeric,
    start_date date,
    end_date date,
    enrollment_code numeric,
    drop_code numeric,
    next_school numeric,
    calendar_id numeric
) WITHOUT OIDS;


--
-- TOC entry 44 (OID 52552933)
-- Name: student_enrollment_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE student_enrollment_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 46 (OID 52552935)
-- Name: address_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE address_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 48 (OID 52552937)
-- Name: people_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE people_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 113 (OID 52552939)
-- Name: students_join_users; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE students_join_users (
    student_id numeric NOT NULL,
    staff_id numeric NOT NULL
);


--
-- TOC entry 50 (OID 52552944)
-- Name: students_join_people_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE students_join_people_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 52 (OID 52552946)
-- Name: students_join_address_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE students_join_address_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 54 (OID 52552948)
-- Name: people_join_contacts_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE people_join_contacts_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 114 (OID 52552950)
-- Name: people_join_contacts; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE people_join_contacts (
    id numeric NOT NULL,
    person_id numeric,
    title character varying(100),
    value character varying(100)
);


--
-- TOC entry 115 (OID 52552955)
-- Name: student_mp_comments; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_mp_comments (
    student_id numeric NOT NULL,
    syear numeric(4,0) NOT NULL,
    marking_period_id numeric NOT NULL,
    "comment" text
);


--
-- TOC entry 116 (OID 52553201)
-- Name: student_field_categories; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_field_categories (
    id numeric NOT NULL,
    title character varying(100),
    sort_order numeric,
    allow_teacher_modify character varying(1)
);


--
-- TOC entry 56 (OID 52553208)
-- Name: student_field_categories_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE student_field_categories_seq
    START 4
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 58 (OID 52553234)
-- Name: calendars_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE calendars_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 117 (OID 52553236)
-- Name: attendance_calendars; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_calendars (
    school_id numeric,
    title character varying(100),
    syear numeric(4,0),
    calendar_id numeric NOT NULL,
    default_calendar character varying(1)
);


--
-- TOC entry 118 (OID 52553243)
-- Name: lunch_period; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE lunch_period (
    student_id numeric,
    school_date date,
    period_id numeric,
    attendance_code numeric,
    attendance_teacher_code numeric,
    attendance_reason character varying(100),
    admin character varying(1),
    course_period_id numeric,
    marking_period_id numeric,
    lunch_period character varying(100),
    table_name numeric
);


--
-- TOC entry 119 (OID 52553248)
-- Name: attendance_code_categories; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE attendance_code_categories (
    id numeric,
    syear numeric(4,0),
    school_id numeric,
    title character varying(255)
);


--
-- TOC entry 60 (OID 52553255)
-- Name: attendance_code_categories_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE attendance_code_categories_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 120 (OID 52553259)
-- Name: user_profiles; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE user_profiles (
    id numeric,
    profile character varying(30),
    title character varying(100)
);


--
-- TOC entry 62 (OID 52553264)
-- Name: user_profiles_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE user_profiles_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 121 (OID 52553266)
-- Name: profile_exceptions; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE profile_exceptions (
    profile_id numeric,
    modname character varying(255),
    can_use character varying(1),
    can_edit character varying(1)
);


--
-- TOC entry 64 (OID 52553271)
-- Name: schedule_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE schedule_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 122 (OID 52553273)
-- Name: student_medical_visits; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_medical_visits (
    id numeric NOT NULL,
    student_id numeric,
    school_date date,
    time_in character varying(20),
    time_out character varying(20),
    reason character varying(100),
    result character varying(100),
    comments character varying(255)
);


--
-- TOC entry 66 (OID 52553280)
-- Name: student_medical_visits_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE student_medical_visits_seq
    START 1
    INCREMENT 1
    MAXVALUE 9223372036854775807
    MINVALUE 1
    CACHE 1;


--
-- TOC entry 123 (OID 52553283)
-- Name: student_gpa_running; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_gpa_running (
    student_id numeric,
    marking_period_id numeric,
    gpa_points numeric,
    gpa_points_weighted numeric,
    divisor numeric
);


--
-- TOC entry 124 (OID 52553289)
-- Name: student_gpa_calculated; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE student_gpa_calculated (
    student_id numeric,
    marking_period_id numeric,
    mp character varying(4),
    gpa numeric,
    weighted_gpa numeric,
    unweighted_gpa numeric,
    class_rank numeric
);


--
-- Data for TOC entry 254 (OID 52552673)
-- Name: course_subjects; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 255 (OID 52552678)
-- Name: courses; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 256 (OID 52552685)
-- Name: school_gradelevels; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO school_gradelevels VALUES (1, 1, 'KG', 'Kindergarten', 2, 1);
INSERT INTO school_gradelevels VALUES (2, 1, '01', '1st', 3, 2);
INSERT INTO school_gradelevels VALUES (3, 1, '02', '2nd', 4, 3);
INSERT INTO school_gradelevels VALUES (4, 1, '03', '3rd', 5, 4);
INSERT INTO school_gradelevels VALUES (5, 1, '04', '4th', 6, 5);
INSERT INTO school_gradelevels VALUES (6, 1, '05', '5th', 7, 6);
INSERT INTO school_gradelevels VALUES (7, 1, '06', '6th', 8, 7);
INSERT INTO school_gradelevels VALUES (8, 1, '07', '7th', 9, 8);
INSERT INTO school_gradelevels VALUES (9, 1, '08', '8th', NULL, 9);


--
-- Data for TOC entry 257 (OID 52552690)
-- Name: custom_fields; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO custom_fields VALUES (200000000, 'select', NULL, 'Gender', 0, 'Male
Female', 1, 'Y', 'Y', NULL);
INSERT INTO custom_fields VALUES (200000001, 'select', NULL, 'Ethnicity', 1, 'White, Non-Hispanic
Black, Non-Hispanic
Amer. Indian or Alaskan Native
Asian or Pacific Islander
Hispanic
Other', 1, 'Y', 'Y', NULL);
INSERT INTO custom_fields VALUES (200000002, 'text', NULL, 'Nickname', 2, NULL, 1, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000003, 'text', NULL, 'Social Security', 3, NULL, 1, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000004, 'date', NULL, 'Birthdate', 4, NULL, 1, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000005, 'select', NULL, 'Language', 5, 'English
Spanish', 1, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000006, 'text', NULL, 'Physician', 6, NULL, 2, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000007, 'text', NULL, 'Physician Phone', 7, NULL, 2, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000008, 'text', NULL, 'Preferred Hospital', 8, NULL, 2, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000009, 'textarea', NULL, 'Comments', 9, NULL, 2, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000010, 'radio', NULL, 'Has Doctor''s Note', 10, NULL, 2, 'Y', NULL, NULL);
INSERT INTO custom_fields VALUES (200000011, 'textarea', NULL, 'Doctor''s Note Comments', 11, NULL, 2, 'Y', NULL, NULL);


--
-- Data for TOC entry 258 (OID 52552695)
-- Name: custom; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 259 (OID 52552700)
-- Name: students; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO students VALUES (1, 'Student', 'Student', 'S', NULL, 'student', 'student', NULL, NULL, 'Male', 'White, Non-Hispanic', 'Bug', NULL, '1996-12-04', 'English', NULL, NULL, NULL, NULL, NULL, NULL);


--
-- Data for TOC entry 260 (OID 52552707)
-- Name: student_medical; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 261 (OID 52552714)
-- Name: student_medical_alerts; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 262 (OID 52552723)
-- Name: staff; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO staff VALUES (2006, 1, NULL, NULL, 'Admin', 'Administrator', 'A', 'admin', 'admin', NULL, NULL, 'admin', NULL, NULL, NULL, NULL);
INSERT INTO staff VALUES (2006, 2, NULL, NULL, 'Parent', 'Parent', 'P', 'parent', 'parent', NULL, NULL, 'parent', NULL, NULL, NULL, NULL);
INSERT INTO staff VALUES (2006, 3, NULL, NULL, 'Teach', 'Teacher', 'T', 'teacher', 'teacher', NULL, NULL, 'teacher', NULL, NULL, NULL, NULL);


--
-- Data for TOC entry 263 (OID 52552728)
-- Name: config; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO config VALUES ('Centre School Software', 2006, 'No');


--
-- Data for TOC entry 264 (OID 52552730)
-- Name: staff_exceptions; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 265 (OID 52552734)
-- Name: attendance_codes; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO attendance_codes VALUES (1, 2006, 1, 'Absent', 'A', 'teacher', 'A', NULL, 0, NULL);
INSERT INTO attendance_codes VALUES (2, 2006, 1, 'Vacation', 'V', 'official', 'A', NULL, 0, NULL);
INSERT INTO attendance_codes VALUES (3, 2006, 1, 'Present', 'P', 'teacher', 'P', 'Y', 0, NULL);
INSERT INTO attendance_codes VALUES (4, 2006, 1, 'Tardy', 'T', 'teacher', 'P', NULL, 0, NULL);
INSERT INTO attendance_codes VALUES (5, 2006, 1, 'Less than 5 minutes late', 'L', 'teacher', 'P', NULL, 0, NULL);
INSERT INTO attendance_codes VALUES (6, 2006, 1, 'Excused Absence', 'E', 'official', 'A', NULL, 0, NULL);
INSERT INTO attendance_codes VALUES (7, 2006, 1, 'Sick', 'S', 'official', 'A', NULL, 0, NULL);


--
-- Data for TOC entry 266 (OID 52552739)
-- Name: attendance_calendar; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 267 (OID 52552744)
-- Name: calendar_events; Type: TABLE DATA; Schema: public; Owner: postgres
--


INSERT INTO school_years VALUES (11, 2006, 1, 'Full Year', 'FY', 1, '2006-08-22', '2007-06-05', NULL, NULL, NULL, NULL, NULL, NULL);

--
-- Data for TOC entry 268 (OID 52552751)
-- Name: school_semesters; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO school_semesters VALUES (1, 2006, 1, 11, 'Semester 1', 'S1', 1, '2006-08-22', '2007-01-07', '2007-01-06', '2007-01-07', NULL, NULL, NULL, NULL);
INSERT INTO school_semesters VALUES (2, 2006, 1, 11, 'Semester 2', 'S2', 2, '2007-01-08', '2007-06-05', '2007-06-04', '2007-06-05', NULL, NULL, NULL, NULL);


--
-- Data for TOC entry 269 (OID 52552756)
-- Name: school_quarters; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO school_quarters VALUES (3, 2006, 1, 1, 'Quarter 1', 'Q1', 1, '2006-08-22', '2006-10-11', '2006-10-10', '2006-10-11', 'Y', NULL, 'Y', NULL);
INSERT INTO school_quarters VALUES (4, 2006, 1, 1, 'Quarter 2', 'Q2', 2, '2006-10-12', '2007-01-07', '2007-01-06', '2007-01-07', 'Y', NULL, 'Y', NULL);
INSERT INTO school_quarters VALUES (5, 2006, 1, 2, 'Quarter 3', 'Q3', 3, '2007-01-08', '2007-03-10', '2007-03-09', '2007-03-10', 'Y', NULL, 'Y', NULL);
INSERT INTO school_quarters VALUES (6, 2006, 1, 2, 'Quarter 4', 'Q4', 4, '2007-03-11', '2007-06-05', '2007-06-06', '2007-06-05', 'Y', NULL, 'Y', NULL);


--
-- Data for TOC entry 270 (OID 52552761)
-- Name: school_progress_periods; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO school_progress_periods VALUES (7, 2006, 1, 3, 'Midterm 1', 'M1', 1, '2006-08-22', '2006-09-22', '2006-09-21', '2006-09-22', 'Y', NULL, NULL, NULL);
INSERT INTO school_progress_periods VALUES (8, 2006, 1, 4, 'Midterm 2', 'M2', 2, '2006-10-12', '2006-11-12', '2006-11-11', '2006-11-12', 'Y', NULL, NULL, NULL);
INSERT INTO school_progress_periods VALUES (9, 2006, 1, 5, 'Midterm 3', 'M3', 3, '2007-01-08', '2007-02-08', '2007-02-07', '2007-02-08', 'Y', NULL, NULL, NULL);
INSERT INTO school_progress_periods VALUES (10, 2006, 1, 6, 'Midterm 4', 'M4', 4, '2007-03-11', '2007-04-11', '2007-04-10', '2007-04-11', 'Y', NULL, NULL, NULL);


--
-- Data for TOC entry 271 (OID 52552768)
-- Name: attendance_period; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 272 (OID 52552773)
-- Name: school_periods; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO school_periods VALUES (1, 2006, 1, 1, 'Full Day', 'FD', 300, NULL, NULL, NULL, 'Y', NULL);
INSERT INTO school_periods VALUES (2, 2006, 1, 2, 'Half Day AM', 'AM', 150, NULL, NULL, NULL, 'Y', NULL);
INSERT INTO school_periods VALUES (3, 2006, 1, 3, 'Half Day PM', 'PM', 150, NULL, NULL, NULL, 'Y', NULL);
INSERT INTO school_periods VALUES (4, 2006, 1, 4, 'Period 1', '01', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (5, 2006, 1, 5, 'Period 2', '02', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (6, 2006, 1, 6, 'Period 3', '03', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (7, 2006, 1, 7, 'Period 4', '04', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (8, 2006, 1, 8, 'Period 5', '05', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (9, 2006, 1, 9, 'Period 6', '06', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (10, 2006, 1, 10, 'Period 7', '07', 0, NULL, NULL, NULL, NULL, NULL);
INSERT INTO school_periods VALUES (11, 2006, 1, 11, 'Period 8', '08', 0, NULL, NULL, NULL, NULL, NULL);


--
-- Data for TOC entry 273 (OID 52552778)
-- Name: course_weights; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 274 (OID 52552783)
-- Name: schedule; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 275 (OID 52552788)
-- Name: course_periods; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 276 (OID 52552793)
-- Name: schedule_requests; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 277 (OID 52552798)
-- Name: address; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 278 (OID 52552800)
-- Name: students_join_address; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 279 (OID 52552805)
-- Name: people; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 280 (OID 52552807)
-- Name: students_join_people; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 281 (OID 52552812)
-- Name: attendance_day; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 282 (OID 52552821)
-- Name: report_card_comments; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO report_card_comments VALUES (1, 2006, 1, NULL, 1, 'Fails to Meet Course Requirements');
INSERT INTO report_card_comments VALUES (2, 2006, 1, NULL, 2, 'Comes to Class Unprepared');
INSERT INTO report_card_comments VALUES (3, 2006, 1, NULL, 3, 'Exerts Positive Influence in Class');


--
-- Data for TOC entry 283 (OID 52552826)
-- Name: report_card_grades; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO report_card_grades VALUES (1, 2006, 1, 'A+', 1, 12.00, 97, 'Consistently superior');
INSERT INTO report_card_grades VALUES (2, 2006, 1, 'A', 2, 11.00, 93, 'Supprior');
INSERT INTO report_card_grades VALUES (3, 2006, 1, 'A-', 3, 10.00, 90, NULL);
INSERT INTO report_card_grades VALUES (4, 2006, 1, 'B+', 4, 9.00, 87, NULL);
INSERT INTO report_card_grades VALUES (5, 2006, 1, 'B', 5, 8.00, 83, 'Above average');
INSERT INTO report_card_grades VALUES (6, 2006, 1, 'B-', 6, 7.00, 80, NULL);
INSERT INTO report_card_grades VALUES (7, 2006, 1, 'C+', 7, 6.00, 77, NULL);
INSERT INTO report_card_grades VALUES (8, 2006, 1, 'C', 8, 5.00, 73, 'Average');
INSERT INTO report_card_grades VALUES (9, 2006, 1, 'C-', 9, 4.00, 70, NULL);
INSERT INTO report_card_grades VALUES (10, 2006, 1, 'D+', 10, 3.00, 67, NULL);
INSERT INTO report_card_grades VALUES (11, 2006, 1, 'D', 11, 2.00, 63, 'Below average');
INSERT INTO report_card_grades VALUES (12, 2006, 1, 'D-', 12, 1.00, 60, NULL);
INSERT INTO report_card_grades VALUES (13, 2006, 1, 'F', 13, 0.00, 0, 'Failing');
INSERT INTO report_card_grades VALUES (14, 2006, 1, 'I', 14, 0.00, 0, 'Incomplete');
INSERT INTO report_card_grades VALUES (15, 2006, 1, 'N/A', 15, 0.00, NULL, NULL);


--
-- Data for TOC entry 284 (OID 52552831)
-- Name: attendance_completed; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 285 (OID 52552836)
-- Name: student_report_card_grades; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 286 (OID 52552841)
-- Name: grades_completed; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 287 (OID 52552856)
-- Name: eligibility_activities; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO eligibility_activities VALUES (1, 2006, 1, 'Boy''s Basketball', '2007-01-01', '2007-04-14');
INSERT INTO eligibility_activities VALUES (2, 2006, 1, 'Chess Team', '2006-09-01', '2007-06-04');
INSERT INTO eligibility_activities VALUES (3, 2006, 1, 'Girl''s Basketball', '2007-01-01', '2007-04-15');


--
-- Data for TOC entry 288 (OID 52552863)
-- Name: eligibility; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 289 (OID 52552868)
-- Name: eligibility_completed; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 290 (OID 52552873)
-- Name: program_config; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'START_DAY', '1');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'START_HOUR', '23');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'START_MINUTE', '30');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'START_M', 'PM');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'END_DAY', '5');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'END_HOUR', '23');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'END_MINUTE', '30');
INSERT INTO program_config VALUES (2006, 1, 'eligibility', 'END_M', 'PM');


--
-- Data for TOC entry 291 (OID 52552878)
-- Name: student_eligibility_activities; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 292 (OID 52552883)
-- Name: gradebook_assignment_types; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 293 (OID 52552892)
-- Name: gradebook_assignments; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 294 (OID 52552897)
-- Name: gradebook_grades; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 295 (OID 52552902)
-- Name: program_user_config; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 296 (OID 52552914)
-- Name: schools; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO schools VALUES (2006, 1, 'Default School', '500 S. Street St.', 'Springfield', 'IL', '62704', 217, NULL, 'Mr. Principal');


--
-- Data for TOC entry 297 (OID 52552921)
-- Name: student_enrollment_codes; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO student_enrollment_codes VALUES (1, 2006, 'Moved from District', 'MOVE', 'Drop');
INSERT INTO student_enrollment_codes VALUES (2, 2006, 'Expelled', 'EXP', 'Drop');
INSERT INTO student_enrollment_codes VALUES (3, 2006, 'Beginning of Year', 'EBY', 'Add');
INSERT INTO student_enrollment_codes VALUES (4, 2006, 'From Other District', 'OTHER', 'Add');
INSERT INTO student_enrollment_codes VALUES (5, 2006, 'Transferred in District', 'TRAN', 'Drop');
INSERT INTO student_enrollment_codes VALUES (6, 2006, 'Transferred in District', 'EMY', 'Add');


--
-- Data for TOC entry 298 (OID 52552928)
-- Name: student_enrollment; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO student_enrollment VALUES (1, 2006, 1, 1, 5, '2006-07-15', NULL, 3, NULL, 1, NULL);


--
-- Data for TOC entry 299 (OID 52552939)
-- Name: students_join_users; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 300 (OID 52552950)
-- Name: people_join_contacts; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 301 (OID 52552955)
-- Name: student_mp_comments; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 302 (OID 52553201)
-- Name: student_field_categories; Type: TABLE DATA; Schema: public; Owner: postgres
--

INSERT INTO student_field_categories VALUES (1, 'General', 1, NULL);
INSERT INTO student_field_categories VALUES (3, 'Address', 2, NULL);
INSERT INTO student_field_categories VALUES (2, 'Medical', 3, NULL);


--
-- Data for TOC entry 303 (OID 52553236)
-- Name: attendance_calendars; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 304 (OID 52553243)
-- Name: lunch_period; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 305 (OID 52553248)
-- Name: attendance_code_categories; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 306 (OID 52553259)
-- Name: user_profiles; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 307 (OID 52553266)
-- Name: profile_exceptions; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 308 (OID 52553273)
-- Name: student_medical_visits; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 309 (OID 52553283)
-- Name: student_gpa_running; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- Data for TOC entry 310 (OID 52553289)
-- Name: student_gpa_calculated; Type: TABLE DATA; Schema: public; Owner: postgres
--



--
-- TOC entry 132 (OID 52553029)
-- Name: custom_desc_ind; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX custom_desc_ind ON custom_fields USING btree (id);


--
-- TOC entry 133 (OID 52553030)
-- Name: custom_desc_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX custom_desc_ind2 ON custom_fields USING btree ("type");


--
-- TOC entry 136 (OID 52553031)
-- Name: custom_ind; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX custom_ind ON custom USING btree (student_id);


CREATE INDEX school_years_ind2 ON school_years USING btree (syear, school_id, start_date, end_date);


CREATE INDEX school_semesters_ind1 ON school_semesters USING btree (year_id);

--
-- TOC entry 157 (OID 52553033)
-- Name: school_semesters_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_semesters_ind2 ON school_semesters USING btree (syear, school_id, start_date, end_date);


--
-- TOC entry 160 (OID 52553035)
-- Name: school_quarters_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_quarters_ind2 ON school_quarters USING btree (syear, school_id, start_date, end_date);


--
-- TOC entry 163 (OID 52553037)
-- Name: school_progress_periods_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_progress_periods_ind2 ON school_progress_periods USING btree (syear, school_id, start_date, end_date);


--
-- TOC entry 179 (OID 52553038)
-- Name: course_periods_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX course_periods_ind1 ON course_periods USING btree (syear);


--
-- TOC entry 127 (OID 52553039)
-- Name: courses_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX courses_ind1 ON courses USING btree (course_id, syear);


--
-- TOC entry 185 (OID 52553041)
-- Name: schedule_requests_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind1 ON schedule_requests USING btree (student_id, course_id, course_weight, syear, school_id);


--
-- TOC entry 186 (OID 52553042)
-- Name: schedule_requests_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind2 ON schedule_requests USING btree (syear, school_id);


--
-- TOC entry 187 (OID 52553043)
-- Name: schedule_requests_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind3 ON schedule_requests USING btree (course_id, course_weight, syear, school_id);


--
-- TOC entry 180 (OID 52553044)
-- Name: course_periods_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX course_periods_ind2 ON course_periods USING btree (course_id, course_weight, syear, school_id);


--
-- TOC entry 194 (OID 52553047)
-- Name: address_3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX address_3 ON address USING btree (zipcode, plus4);


--
-- TOC entry 195 (OID 52553048)
-- Name: address_4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX address_4 ON address USING btree (street);


--
-- TOC entry 200 (OID 52553049)
-- Name: students_join_address_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX students_join_address_ind1 ON students_join_address USING btree (student_id);


--
-- TOC entry 197 (OID 52553050)
-- Name: stu_addr_meets_2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX stu_addr_meets_2 ON students_join_address USING btree (address_id);


--
-- TOC entry 198 (OID 52553051)
-- Name: stu_addr_meets_3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX stu_addr_meets_3 ON students_join_address USING btree (primary_residence);


--
-- TOC entry 199 (OID 52553052)
-- Name: stu_addr_meets_4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX stu_addr_meets_4 ON students_join_address USING btree (legal_residence);


--
-- TOC entry 202 (OID 52553054)
-- Name: sys_c007322; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX sys_c007322 ON students_join_address USING btree (id, student_id, address_id);


--
-- TOC entry 203 (OID 52553055)
-- Name: people_1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX people_1 ON people USING btree (last_name, first_name);


--
-- TOC entry 204 (OID 52553057)
-- Name: people_3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX people_3 ON people USING btree (person_id, last_name, first_name, middle_name);


--
-- TOC entry 209 (OID 52553058)
-- Name: students_join_people_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX students_join_people_ind1 ON students_join_people USING btree (student_id);


--
-- TOC entry 206 (OID 52553059)
-- Name: relations_meets_2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX relations_meets_2 ON students_join_people USING btree (person_id);


--
-- TOC entry 207 (OID 52553060)
-- Name: relations_meets_5; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX relations_meets_5 ON students_join_people USING btree (id);


--
-- TOC entry 175 (OID 52553061)
-- Name: schedule_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_ind2 ON schedule USING btree (course_period_id);


--
-- TOC entry 176 (OID 52553062)
-- Name: schedule_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_ind3 ON schedule USING btree (student_id, marking_period_id, start_date, end_date);


--
-- TOC entry 181 (OID 52553063)
-- Name: course_periods_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX course_periods_ind3 ON course_periods USING btree (course_period_id);


--
-- TOC entry 182 (OID 52553064)
-- Name: course_periods_ind4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX course_periods_ind4 ON course_periods USING btree (period_id);


--
-- TOC entry 171 (OID 52553065)
-- Name: school_periods_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_periods_ind1 ON school_periods USING btree (period_id, syear);


--
-- TOC entry 166 (OID 52553068)
-- Name: attendance_period_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_period_ind2 ON attendance_period USING btree (period_id);


--
-- TOC entry 167 (OID 52553069)
-- Name: attendance_period_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_period_ind3 ON attendance_period USING btree (attendance_code);


--
-- TOC entry 152 (OID 52553071)
-- Name: attendance_codes_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_codes_ind2 ON attendance_codes USING btree (syear, school_id);


--
-- TOC entry 153 (OID 52553072)
-- Name: attendance_codes_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_codes_ind3 ON attendance_codes USING btree (short_name);


--
-- TOC entry 147 (OID 52553073)
-- Name: staff_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX staff_ind1 ON staff USING btree (staff_id, syear);


--
-- TOC entry 148 (OID 52553074)
-- Name: staff_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX staff_ind2 ON staff USING btree (last_name, first_name);


--
-- TOC entry 188 (OID 52553075)
-- Name: schedule_requests_ind4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind4 ON schedule_requests USING btree (with_teacher_id);


--
-- TOC entry 189 (OID 52553076)
-- Name: schedule_requests_ind5; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind5 ON schedule_requests USING btree (not_teacher_id);


--
-- TOC entry 191 (OID 52553077)
-- Name: schedule_requests_ind7; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind7 ON schedule_requests USING btree (not_period_id);


--
-- TOC entry 190 (OID 52553078)
-- Name: schedule_requests_ind6; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind6 ON schedule_requests USING btree (with_period_id);


--
-- TOC entry 192 (OID 52553079)
-- Name: schedule_requests_ind8; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_requests_ind8 ON schedule_requests USING btree (request_id);


--
-- TOC entry 234 (OID 52553080)
-- Name: program_user_config_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX program_user_config_ind1 ON program_user_config USING btree (user_id, program);


--
-- TOC entry 237 (OID 52553081)
-- Name: student_enrollment_1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_enrollment_1 ON student_enrollment USING btree (student_id, enrollment_code);


--
-- TOC entry 238 (OID 52553082)
-- Name: student_enrollment_2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_enrollment_2 ON student_enrollment USING btree (grade_id);


--
-- TOC entry 239 (OID 52553083)
-- Name: student_enrollment_3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_enrollment_3 ON student_enrollment USING btree (syear, student_id, school_id, grade_id);


--
-- TOC entry 139 (OID 52553084)
-- Name: name; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX name ON students USING btree (last_name, first_name, middle_name);


--
-- TOC entry 141 (OID 52553085)
-- Name: ssn; Type: INDEX; Schema: public; Owner: postgres
--

--CREATE INDEX ssn ON students USING btree (soc_sec_no);


--
-- TOC entry 140 (OID 52553086)
-- Name: sex; Type: INDEX; Schema: public; Owner: postgres
--

--CREATE INDEX sex ON students USING btree (gender);


--
-- TOC entry 138 (OID 52553087)
-- Name: ethnic; Type: INDEX; Schema: public; Owner: postgres
--

--CREATE INDEX ethnic ON students USING btree (ethnicity);


--
-- TOC entry 240 (OID 52553088)
-- Name: student_enrollment_6; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_enrollment_6 ON student_enrollment USING btree (start_date, end_date);


--
-- TOC entry 208 (OID 52553103)
-- Name: relations_meets_6; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX relations_meets_6 ON students_join_people USING btree (custody, emergency);


--
-- TOC entry 128 (OID 52553108)
-- Name: courses_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX courses_ind2 ON courses USING btree (subject_id);


--
-- TOC entry 177 (OID 52553111)
-- Name: schedule_ind4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_ind4 ON schedule USING btree (syear, school_id);


--
-- TOC entry 174 (OID 52553112)
-- Name: schedule_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schedule_ind1 ON schedule USING btree (course_id, course_weight);


--
-- TOC entry 150 (OID 52553113)
-- Name: staff_ind4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX staff_ind4 ON staff USING btree (username, syear);


--
-- TOC entry 125 (OID 52553118)
-- Name: course_subjects_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX course_subjects_ind1 ON course_subjects USING btree (syear, school_id, subject_id);


--
-- TOC entry 168 (OID 52553121)
-- Name: attendance_period_ind4; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_period_ind4 ON attendance_period USING btree (school_date);


--
-- TOC entry 165 (OID 52553122)
-- Name: attendance_period_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_period_ind1 ON attendance_period USING btree (student_id);


--
-- TOC entry 169 (OID 52553125)
-- Name: attendance_period_ind5; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_period_ind5 ON attendance_period USING btree (attendance_code);


--
-- TOC entry 130 (OID 52553134)
-- Name: school_gradelevels_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_gradelevels_ind1 ON school_gradelevels USING btree (school_id);


--
-- TOC entry 235 (OID 52553137)
-- Name: schools_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX schools_ind1 ON schools USING btree (syear);


-- TOC entry 159 (OID 52553154)
-- Name: school_quarters_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_quarters_ind1 ON school_quarters USING btree (semester_id);


--
-- TOC entry 162 (OID 52553157)
-- Name: school_progress_periods_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX school_progress_periods_ind1 ON school_progress_periods USING btree (quarter_id);


--
-- TOC entry 217 (OID 52553160)
-- Name: student_report_card_grades_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_report_card_grades_ind1 ON student_report_card_grades USING btree (school_id);

CREATE INDEX student_report_card_comments_ind1 ON student_report_card_comments USING btree (school_id);


--
-- TOC entry 244 (OID 52553169)
-- Name: people_join_contacts_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX people_join_contacts_ind1 ON people_join_contacts USING btree (person_id);


--
-- TOC entry 224 (OID 52553172)
-- Name: program_config_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX program_config_ind1 ON program_config USING btree (program, school_id, syear);


--
-- TOC entry 232 (OID 52553175)
-- Name: gradebook_grades_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gradebook_grades_ind1 ON gradebook_grades USING btree (assignment_id);


--
-- TOC entry 228 (OID 52553178)
-- Name: gradebook_assignments_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gradebook_assignments_ind1 ON gradebook_assignments USING btree (staff_id, marking_period_id);


--
-- TOC entry 229 (OID 52553179)
-- Name: gradebook_assignments_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gradebook_assignments_ind2 ON gradebook_assignments USING btree (course_id, course_period_id);


--
-- TOC entry 230 (OID 52553180)
-- Name: gradebook_assignments_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gradebook_assignments_ind3 ON gradebook_assignments USING btree (assignment_type_id);


--
-- TOC entry 227 (OID 52553183)
-- Name: gradebook_assignment_types_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX gradebook_assignment_types_ind1 ON gradebook_assignments USING btree (staff_id, course_id);


--
-- TOC entry 214 (OID 52553186)
-- Name: report_card_grades_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX report_card_grades_ind1 ON report_card_grades USING btree (syear, school_id);


--
-- TOC entry 212 (OID 52553189)
-- Name: report_card_comments_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX report_card_comments_ind1 ON report_card_comments USING btree (syear, school_id);


--
-- TOC entry 225 (OID 52553190)
-- Name: student_eligibility_activities_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_eligibility_activities_ind1 ON student_eligibility_activities USING btree (student_id);


--
-- TOC entry 222 (OID 52553191)
-- Name: eligibility_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX eligibility_ind1 ON eligibility USING btree (student_id, course_period_id, school_date);


--
-- TOC entry 220 (OID 52553194)
-- Name: eligibility_activities_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX eligibility_activities_ind1 ON eligibility_activities USING btree (school_id, syear);


--
-- TOC entry 143 (OID 52553197)
-- Name: student_medical_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_medical_ind1 ON student_medical USING btree (student_id);


--
-- TOC entry 145 (OID 52553200)
-- Name: student_medical_alerts_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_medical_alerts_ind1 ON student_medical_alerts USING btree (student_id);


--
-- TOC entry 134 (OID 52553210)
-- Name: custom_fields_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX custom_fields_ind3 ON custom_fields USING btree (category_id);


--
-- TOC entry 241 (OID 52553211)
-- Name: student_enrollment_7; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_enrollment_7 ON student_enrollment USING btree (school_id);


--
-- TOC entry 149 (OID 52553232)
-- Name: staff_ind3; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX staff_ind3 ON staff USING btree (schools);


--
-- TOC entry 183 (OID 52553233)
-- Name: course_periods_ind5; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX course_periods_ind5 ON course_periods USING btree (parent_id);


--
-- TOC entry 248 (OID 52553253)
-- Name: attendance_code_categories_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_code_categories_ind1 ON attendance_code_categories USING btree (id);


--
-- TOC entry 249 (OID 52553254)
-- Name: attendance_code_categories_ind2; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX attendance_code_categories_ind2 ON attendance_code_categories USING btree (syear, school_id);


--
-- TOC entry 250 (OID 52553282)
-- Name: student_medical_visits_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_medical_visits_ind1 ON student_medical_visits USING btree (student_id);


--
-- TOC entry 252 (OID 52553288)
-- Name: student_gpa_running_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_gpa_running_ind1 ON student_gpa_running USING btree (marking_period_id, student_id);


--
-- TOC entry 253 (OID 52553294)
-- Name: student_gpa_calculated_ind1; Type: INDEX; Schema: public; Owner: postgres
--

CREATE INDEX student_gpa_calculated_ind1 ON student_gpa_calculated USING btree (marking_period_id, student_id);


--
-- TOC entry 246 (OID 52552960)
-- Name: student_mp_comments_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_mp_comments
    ADD CONSTRAINT student_mp_comments_pkey PRIMARY KEY (student_id, syear, marking_period_id);


--
-- TOC entry 151 (OID 52553089)
-- Name: staff_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY staff
    ADD CONSTRAINT staff_pkey PRIMARY KEY (staff_id);


--
-- TOC entry 142 (OID 52553091)
-- Name: students_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY students
    ADD CONSTRAINT students_pkey PRIMARY KEY (student_id);


--
-- TOC entry 242 (OID 52553093)
-- Name: student_enrollment_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_enrollment
    ADD CONSTRAINT student_enrollment_pkey PRIMARY KEY (id);


--
-- TOC entry 201 (OID 52553095)
-- Name: students_join_address_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY students_join_address
    ADD CONSTRAINT students_join_address_pkey PRIMARY KEY (id);


--
-- TOC entry 137 (OID 52553097)
-- Name: custom_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY custom
    ADD CONSTRAINT custom_pkey PRIMARY KEY (student_id);


--
-- TOC entry 196 (OID 52553099)
-- Name: address_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY address
    ADD CONSTRAINT address_pkey PRIMARY KEY (address_id);


--
-- TOC entry 210 (OID 52553101)
-- Name: students_join_people_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY students_join_people
    ADD CONSTRAINT students_join_people_pkey PRIMARY KEY (id);


--
-- TOC entry 205 (OID 52553104)
-- Name: people_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY people
    ADD CONSTRAINT people_pkey PRIMARY KEY (person_id);


--
-- TOC entry 129 (OID 52553106)
-- Name: courses_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY courses
    ADD CONSTRAINT courses_pkey PRIMARY KEY (course_id);


--
-- TOC entry 184 (OID 52553109)
-- Name: course_periods_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY course_periods
    ADD CONSTRAINT course_periods_pkey PRIMARY KEY (course_period_id);


--
-- TOC entry 193 (OID 52553114)
-- Name: schedule_requests_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY schedule_requests
    ADD CONSTRAINT schedule_requests_pkey PRIMARY KEY (request_id);


--
-- TOC entry 126 (OID 52553116)
-- Name: course_subjects_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY course_subjects
    ADD CONSTRAINT course_subjects_pkey PRIMARY KEY (subject_id);


--
-- TOC entry 173 (OID 52553119)
-- Name: course_weights_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY course_weights
    ADD CONSTRAINT course_weights_pkey PRIMARY KEY (course_id, course_weight);


--
-- TOC entry 170 (OID 52553123)
-- Name: attendance_period_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY attendance_period
    ADD CONSTRAINT attendance_period_pkey PRIMARY KEY (student_id, school_date, period_id);


--
-- TOC entry 154 (OID 52553126)
-- Name: attendance_codes_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY attendance_codes
    ADD CONSTRAINT attendance_codes_pkey PRIMARY KEY (id);


--
-- TOC entry 211 (OID 52553130)
-- Name: attendance_day_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY attendance_day
    ADD CONSTRAINT attendance_day_pkey PRIMARY KEY (student_id, school_date);


--
-- TOC entry 131 (OID 52553132)
-- Name: school_gradelevels_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY school_gradelevels
    ADD CONSTRAINT school_gradelevels_pkey PRIMARY KEY (id);


--
-- TOC entry 236 (OID 52553135)
-- Name: schools_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY schools
    ADD CONSTRAINT schools_pkey PRIMARY KEY (id);


--
-- TOC entry 172 (OID 52553138)
-- Name: school_periods_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY school_periods
    ADD CONSTRAINT school_periods_pkey PRIMARY KEY (period_id);


--
-- TOC entry 216 (OID 52553140)
-- Name: attendance_completed_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY attendance_completed
    ADD CONSTRAINT attendance_completed_pkey PRIMARY KEY (staff_id, school_date, period_id);


--
-- TOC entry 223 (OID 52553142)
-- Name: eligibility_completed_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY eligibility_completed
    ADD CONSTRAINT eligibility_completed_pkey PRIMARY KEY (staff_id, school_date, period_id);


--
-- TOC entry 219 (OID 52553144)
-- Name: grades_completed_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY grades_completed
    ADD CONSTRAINT grades_completed_pkey PRIMARY KEY (staff_id, marking_period_id, period_id);


--
-- TOC entry 243 (OID 52553146)
-- Name: students_join_users_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY students_join_users
    ADD CONSTRAINT students_join_users_pkey PRIMARY KEY (student_id, staff_id);


--
-- TOC entry 135 (OID 52553148)
-- Name: custom_fields_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY custom_fields
    ADD CONSTRAINT custom_fields_pkey PRIMARY KEY (id);


ALTER TABLE ONLY school_years
   ADD CONSTRAINT school_years_pkey PRIMARY KEY (marking_period_id);


--
-- TOC entry 158 (OID 52553150)
-- Name: school_semesters_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY school_semesters
    ADD CONSTRAINT school_semesters_pkey PRIMARY KEY (marking_period_id);


--
-- TOC entry 161 (OID 52553152)
-- Name: school_quarters_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY school_quarters
    ADD CONSTRAINT school_quarters_pkey PRIMARY KEY (marking_period_id);


--
-- TOC entry 164 (OID 52553155)
-- Name: school_progress_periods_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY school_progress_periods
    ADD CONSTRAINT school_progress_periods_pkey PRIMARY KEY (marking_period_id);


--
-- TOC entry 218 (OID 52553158)
-- Name: student_report_card_grades_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_report_card_grades
    ADD CONSTRAINT student_report_card_grades_pkey PRIMARY KEY (syear, student_id, course_period_id, marking_period_id);

ALTER table ONLY student_report_card_comments
    ADD CONSTRAINT student_report_card_comments_pkey PRIMARY KEY (syear, student_id, course_period_id, marking_period_id, report_card_comment_id);


--
-- TOC entry 245 (OID 52553167)
-- Name: people_join_contacts_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY people_join_contacts
    ADD CONSTRAINT people_join_contacts_pkey PRIMARY KEY (id);


--
-- TOC entry 156 (OID 52553170)
-- Name: calendar_events_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY calendar_events
    ADD CONSTRAINT calendar_events_pkey PRIMARY KEY (id);


--
-- TOC entry 231 (OID 52553176)
-- Name: gradebook_assignments_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY gradebook_assignments
    ADD CONSTRAINT gradebook_assignments_pkey PRIMARY KEY (assignment_id);


--
-- TOC entry 226 (OID 52553181)
-- Name: gradebook_assignment_types_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY gradebook_assignment_types
    ADD CONSTRAINT gradebook_assignment_types_pkey PRIMARY KEY (assignment_type_id);


--
-- TOC entry 215 (OID 52553184)
-- Name: report_card_grades_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY report_card_grades
    ADD CONSTRAINT report_card_grades_pkey PRIMARY KEY (id);


--
-- TOC entry 213 (OID 52553187)
-- Name: report_card_comments_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY report_card_comments
    ADD CONSTRAINT report_card_comments_pkey PRIMARY KEY (id);


--
-- TOC entry 221 (OID 52553192)
-- Name: eligibility_activities_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY eligibility_activities
    ADD CONSTRAINT eligibility_activities_pkey PRIMARY KEY (id);


--
-- TOC entry 144 (OID 52553195)
-- Name: student_medical_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_medical
    ADD CONSTRAINT student_medical_pkey PRIMARY KEY (id);


--
-- TOC entry 146 (OID 52553198)
-- Name: student_medical_alerts_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_medical_alerts
    ADD CONSTRAINT student_medical_alerts_pkey PRIMARY KEY (id);


--
-- TOC entry 247 (OID 52553206)
-- Name: student_field_categories_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_field_categories
    ADD CONSTRAINT student_field_categories_pkey PRIMARY KEY (id);


--
-- TOC entry 155 (OID 52553241)
-- Name: attendance_calendar_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY attendance_calendar
    ADD CONSTRAINT attendance_calendar_pkey PRIMARY KEY (syear, school_id, school_date, calendar_id);


--
-- TOC entry 233 (OID 52553257)
-- Name: gradebook_grades_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY gradebook_grades
    ADD CONSTRAINT gradebook_grades_pkey PRIMARY KEY (student_id, assignment_id, course_period_id);


--
-- TOC entry 251 (OID 52553278)
-- Name: student_medical_visits_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY student_medical_visits
    ADD CONSTRAINT student_medical_visits_pkey PRIMARY KEY (id);


--
-- TOC entry 178 (OID 52553295)
-- Name: schedule_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY schedule
    ADD CONSTRAINT schedule_pkey PRIMARY KEY (syear, student_id, course_id, course_weight, course_period_id, start_date);


--
-- TOC entry 3 (OID 52552671)
-- Name: schedule_requests_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('schedule_requests_seq', 1, true);


--
-- TOC entry 5 (OID 52552683)
-- Name: course_subjects_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('course_subjects_seq', 1, true);


--
-- TOC entry 7 (OID 52552705)
-- Name: students_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('students_seq', 1, true);


--
-- TOC entry 9 (OID 52552712)
-- Name: student_medical_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('student_medical_seq', 1, false);


--
-- TOC entry 11 (OID 52552719)
-- Name: student_medical_alerts_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('student_medical_alerts_seq', 1, false);


--
-- TOC entry 13 (OID 52552721)
-- Name: staff_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('staff_seq', 3, true);


--
-- TOC entry 15 (OID 52552732)
-- Name: attendance_codes_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('attendance_codes_seq', 7, true);


--
-- TOC entry 17 (OID 52552749)
-- Name: calendar_events_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('calendar_events_seq', 1, false);


--
-- TOC entry 19 (OID 52552766)
-- Name: marking_period_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('marking_period_seq', 11, true);


--
-- TOC entry 21 (OID 52552817)
-- Name: report_card_grades_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('report_card_grades_seq', 15, true);


--
-- TOC entry 23 (OID 52552819)
-- Name: report_card_comments_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('report_card_comments_seq', 3, true);


--
-- TOC entry 25 (OID 52552861)
-- Name: eligibility_activities_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('eligibility_activities_seq', 3, true);


--
-- TOC entry 27 (OID 52552888)
-- Name: gradebook_assignment_types_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('gradebook_assignment_types_seq', 1, false);


--
-- TOC entry 29 (OID 52552890)
-- Name: gradebook_assignments_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('gradebook_assignments_seq', 1, true);


--
-- TOC entry 31 (OID 52552904)
-- Name: courses_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('courses_seq', 1, true);


--
-- TOC entry 33 (OID 52552906)
-- Name: school_periods_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('school_periods_seq', 11, true);


--
-- TOC entry 35 (OID 52552908)
-- Name: school_gradelevels_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('school_gradelevels_seq', 9, true);


--
-- TOC entry 37 (OID 52552910)
-- Name: course_periods_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('course_periods_seq', 1, true);


--
-- TOC entry 39 (OID 52552912)
-- Name: schools_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('schools_seq', 1, true);


--
-- TOC entry 41 (OID 52552919)
-- Name: custom_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('custom_seq', 1, true);


--
-- TOC entry 43 (OID 52552926)
-- Name: student_enrollment_codes_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('student_enrollment_codes_seq', 6, true);


--
-- TOC entry 45 (OID 52552933)
-- Name: student_enrollment_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('student_enrollment_seq', 1, true);


--
-- TOC entry 47 (OID 52552935)
-- Name: address_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('address_seq', 1, true);


--
-- TOC entry 49 (OID 52552937)
-- Name: people_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('people_seq', 1, true);


--
-- TOC entry 51 (OID 52552944)
-- Name: students_join_people_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('students_join_people_seq', 1, true);


--
-- TOC entry 53 (OID 52552946)
-- Name: students_join_address_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('students_join_address_seq', 1, true);


--
-- TOC entry 55 (OID 52552948)
-- Name: people_join_contacts_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('people_join_contacts_seq', 1, true);


--
-- TOC entry 57 (OID 52553208)
-- Name: student_field_categories_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('student_field_categories_seq', 3, false);


--
-- TOC entry 59 (OID 52553234)
-- Name: calendars_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('calendars_seq', 1, false);


--
-- TOC entry 61 (OID 52553255)
-- Name: attendance_code_categories_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('attendance_code_categories_seq', 1, false);


--
-- TOC entry 63 (OID 52553264)
-- Name: user_profiles_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('user_profiles_seq', 1, false);


--
-- TOC entry 65 (OID 52553271)
-- Name: schedule_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('schedule_seq', 1, false);


--
-- TOC entry 67 (OID 52553280)
-- Name: student_medical_visits_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval ('student_medical_visits_seq', 1, false);


--
-- Name: portal_notes; Type: TABLE; Schema: public; Owner: postgres; Tablespace:
--

CREATE TABLE portal_notes (
    id numeric,
    school_id numeric,
    syear numeric(4,0),
    title character varying(255),
    content character varying(5000),
    sort_order numeric,
    published_user numeric,
    published_date timestamp(0) without time zone,
    start_date date,
    end_date date,
    published_profiles character varying(255)
);


--
-- Name: address_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres; Tablespace:
--

ALTER TABLE ONLY portal_notes
    ADD CONSTRAINT portal_notes_pkey PRIMARY KEY (id);

--
-- Name: portal_notes_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE portal_notes_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- Name: portal_notes_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval('portal_notes_seq', 1, true);
